@@ -4,10 +4,10 @@ use std::{env, io};
 fn main() {
     let pkg_version = env!("CARGO_PKG_VERSION");
     let version = match env::var_os("PROFILE") {
-        Some(profile) if profile == "release" => format!("v{}", pkg_version),
-        _ => git_version().unwrap_or_else(|| format!("v{}-unknown", pkg_version)),
+        Some(profile) if profile == "release" => format!("v{pkg_version}"),
+        _ => git_version().unwrap_or_else(|| format!("v{pkg_version}-unknown")),
     };
-    println!("cargo:rustc-env=ZOXIDE_VERSION={}", version);
+    println!("cargo:rustc-env=ZOXIDE_VERSION={version}");
 
     // Since we are generating completions in the package directory, we need to set this so that
     // Cargo doesn't rebuild every time.
@@ -22,7 +22,7 @@ fn main() {
 fn git_version() -> Option<String> {
     let dir = env!("CARGO_MANIFEST_DIR");
     let mut git = Command::new("git");
-    git.args(&["-C", dir, "describe", "--tags", "--match=v*.*.*", "--always", "--broken"]);
+    git.args(["-C", dir, "describe", "--tags", "--match=v*.*.*", "--always", "--broken"]);
 
     let output = git.output().ok()?;
     if !output.status.success() || output.stdout.is_empty() || !output.stderr.is_empty() {
@@ -32,7 +32,7 @@ fn git_version() -> Option<String> {
 }
 
 fn generate_completions() -> io::Result<()> {
-    #[path = "src/cmd/_cmd.rs"]
+    #[path = "src/cmd/cmd.rs"]
     mod cmd;
 
     use clap::CommandFactory;
