@@ -1,7 +1,7 @@
 #![allow(clippy::single_component_path_imports)]
 
 // rstest_reuse must be imported at the top of the crate.
-#[cfg(test)]
+#[cfg(all(test, feature = "nix-dev"))]
 use rstest_reuse;
 
 mod cmd;
@@ -11,26 +11,28 @@ mod error;
 mod shell;
 mod util;
 
+use std::env;
 use std::io::{self, Write};
-use std::{env, process};
+use std::process::ExitCode;
 
 use clap::Parser;
 
 use crate::cmd::{Cmd, Run};
 use crate::error::SilentExit;
 
-pub fn main() {
+pub fn main() -> ExitCode {
     // Forcibly disable backtraces.
     env::remove_var("RUST_LIB_BACKTRACE");
     env::remove_var("RUST_BACKTRACE");
 
-    if let Err(e) = Cmd::parse().run() {
-        match e.downcast::<SilentExit>() {
-            Ok(SilentExit { code }) => process::exit(code),
+    match Cmd::parse().run() {
+        Ok(()) => ExitCode::SUCCESS,
+        Err(e) => match e.downcast::<SilentExit>() {
+            Ok(SilentExit { code }) => code.into(),
             Err(e) => {
-                let _ = writeln!(io::stderr(), "zoxide: {:?}", e);
-                process::exit(1);
+                let _ = writeln!(io::stderr(), "zoxide: {e:?}");
+                ExitCode::FAILURE
             }
-        }
+        },
     }
 }
