@@ -57,7 +57,7 @@ mod tests {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
         let source = Bash(&opts).render().unwrap();
         Command::new("bash")
-            .args(&["--noprofile", "--norc", "-e", "-u", "-o", "pipefail", "-c", &source])
+            .args(["--noprofile", "--norc", "-e", "-u", "-o", "pipefail", "-c", &source])
             .assert()
             .success()
             .stdout("")
@@ -70,7 +70,7 @@ mod tests {
         let source = Bash(&opts).render().unwrap();
 
         Command::new("shellcheck")
-            .args(&["--enable", "all", "--shell", "bash", "-"])
+            .args(["--enable", "all", "--shell", "bash", "-"])
             .write_stdin(source)
             .assert()
             .success()
@@ -85,7 +85,7 @@ mod tests {
         source.push('\n');
 
         Command::new("shfmt")
-            .args(&["-d", "-s", "-ln", "bash", "-i", "4", "-ci", "-"])
+            .args(["-d", "-s", "-ln", "bash", "-i", "4", "-ci", "-"])
             .write_stdin(source)
             .assert()
             .success()
@@ -105,7 +105,7 @@ mod tests {
             source.push('\n');
         }
 
-        Command::new("elvish").args(&["-c", &source, "-norc"]).assert().success().stdout("").stderr("");
+        Command::new("elvish").args(["-c", &source, "-norc"]).assert().success().stdout("").stderr("");
     }
 
     #[apply(opts)]
@@ -118,7 +118,7 @@ mod tests {
 
         Command::new("fish")
             .env("HOME", tempdir)
-            .args(&["--command", &source, "--private"])
+            .args(["--command", &source, "--no-config", "--private"])
             .assert()
             .success()
             .stdout("")
@@ -152,7 +152,7 @@ mod tests {
         let tempdir = tempdir.path();
 
         let assert =
-            Command::new("nu").env("HOME", tempdir).args(&["--commands", &source]).assert().success().stderr("");
+            Command::new("nu").env("HOME", tempdir).args(["--commands", &source]).assert().success().stderr("");
 
         if opts.hook != InitHook::Pwd {
             assert.stdout("");
@@ -165,7 +165,7 @@ mod tests {
         let source = Posix(&opts).render().unwrap();
 
         let assert = Command::new("bash")
-            .args(&["--posix", "--noprofile", "--norc", "-e", "-u", "-o", "pipefail", "-c", &source])
+            .args(["--posix", "--noprofile", "--norc", "-e", "-u", "-o", "pipefail", "-c", &source])
             .assert()
             .success()
             .stderr("");
@@ -179,7 +179,7 @@ mod tests {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
         let source = Posix(&opts).render().unwrap();
 
-        let assert = Command::new("dash").args(&["-e", "-u", "-c", &source]).assert().success().stderr("");
+        let assert = Command::new("dash").args(["-e", "-u", "-c", &source]).assert().success().stderr("");
         if opts.hook != InitHook::Pwd {
             assert.stdout("");
         }
@@ -191,7 +191,7 @@ mod tests {
         let source = Posix(&opts).render().unwrap();
 
         Command::new("shellcheck")
-            .args(&["--enable", "all", "--shell", "sh", "-"])
+            .args(["--enable", "all", "--shell", "sh", "-"])
             .write_stdin(source)
             .assert()
             .success()
@@ -206,7 +206,7 @@ mod tests {
         source.push('\n');
 
         Command::new("shfmt")
-            .args(&["-d", "-s", "-ln", "posix", "-i", "4", "-ci", "-"])
+            .args(["-d", "-s", "-ln", "posix", "-i", "4", "-ci", "-"])
             .write_stdin(source)
             .assert()
             .success()
@@ -221,7 +221,7 @@ mod tests {
         Powershell(&opts).render_into(&mut source).unwrap();
 
         Command::new("pwsh")
-            .args(&["-NoLogo", "-NonInteractive", "-NoProfile", "-Command", &source])
+            .args(["-NoLogo", "-NonInteractive", "-NoProfile", "-Command", &source])
             .assert()
             .success()
             .stdout("")
@@ -234,7 +234,7 @@ mod tests {
         let mut source = Xonsh(&opts).render().unwrap();
         source.push('\n');
 
-        Command::new("black").args(&["--check", "--diff", "-"]).write_stdin(source).assert().success().stdout("");
+        Command::new("black").args(["--check", "--diff", "-"]).write_stdin(source).assert().success().stdout("");
     }
 
     #[apply(opts)]
@@ -242,7 +242,7 @@ mod tests {
         let opts = Opts { cmd, hook, echo, resolve_symlinks };
         let source = Xonsh(&opts).render().unwrap();
 
-        Command::new("mypy").args(&["--command", &source, "--strict"]).assert().success().stderr("");
+        Command::new("mypy").args(["--command", &source, "--strict"]).assert().success().stderr("");
     }
 
     #[apply(opts)]
@@ -252,7 +252,7 @@ mod tests {
         source.push('\n');
 
         Command::new("pylint")
-            .args(&["--from-stdin", "--persistent=n", "zoxide"])
+            .args(["--from-stdin", "--persistent=n", "zoxide"])
             .write_stdin(source)
             .assert()
             .success()
@@ -268,7 +268,7 @@ mod tests {
         let tempdir = tempdir.path().to_str().unwrap();
 
         Command::new("xonsh")
-            .args(&["-c", &source, "--no-rc"])
+            .args(["-c", &source, "--no-rc"])
             .env("HOME", tempdir)
             .assert()
             .success()
@@ -283,7 +283,7 @@ mod tests {
 
         // ShellCheck doesn't support zsh yet: https://github.com/koalaman/shellcheck/issues/809
         Command::new("shellcheck")
-            .args(&["--enable", "all", "--shell", "bash", "-"])
+            .args(["--enable", "all", "--shell", "bash", "-"])
             .write_stdin(source)
             .assert()
             .success()
@@ -297,7 +297,7 @@ mod tests {
         let source = Zsh(&opts).render().unwrap();
 
         Command::new("zsh")
-            .args(&["-e", "-u", "-o", "pipefail", "--no-globalrcs", "--no-rcs", "-c", &source])
+            .args(["-e", "-u", "-o", "pipefail", "--no-globalrcs", "--no-rcs", "-c", &source])
             .assert()
             .success()
             .stdout("")
