@@ -1,100 +1,147 @@
-use std::env;
+use std::ffi::OsStr;
 use std::fs::{self, File, OpenOptions};
 use std::io::{self, Read, Write};
-use std::mem;
 use std::path::{Component, Path, PathBuf};
-use std::process::Command;
-use std::process::{Child, ChildStdin, Stdio};
+use std::process::{Child, Command, Stdio};
 use std::time::SystemTime;
+use std::{env, mem};
 
 #[cfg(windows)]
 use anyhow::anyhow;
 use anyhow::{bail, Context, Result};
 
-use crate::config;
-use crate::db::Epoch;
+use crate::db::{Dir, Epoch};
 use crate::error::SilentExit;
 
-pub struct Fzf {
-    child: Child,
-}
+pub const SECOND: Epoch = 1;
+pub const MINUTE: Epoch = 60 * SECOND;
+pub const HOUR: Epoch = 60 * MINUTE;
+pub const DAY: Epoch = 24 * HOUR;
+pub const WEEK: Epoch = 7 * DAY;
+pub const MONTH: Epoch = 30 * DAY;
+
+pub struct Fzf(Command);
 
 impl Fzf {
-    pub fn new(multiple: bool) -> Result<Self> {
-        const ERR_FZF_NOT_FOUND: &str = "could not find fzf, is it installed?";
+    const ERR_FZF_NOT_FOUND: &str = "could not find fzf, is it installed?";
 
+    pub fn new() -> Result<Self> {
         // On Windows, CreateProcess implicitly searches the current working
         // directory for the executable, which is a potential security issue.
         // Instead, we resolve the path to the executable and then pass it to
         // CreateProcess.
         #[cfg(windows)]
-        let mut command = Command::new(which::which("fzf.exe").map_err(|_| anyhow!(ERR_FZF_NOT_FOUND))?);
+        let program = which::which("fzf.exe").map_err(|_| anyhow!(Self::ERR_FZF_NOT_FOUND))?;
         #[cfg(not(windows))]
-        let mut command = Command::new("fzf");
-        if multiple {
-            command.arg("-m");
-        }
-        command.arg("--nth=2..").stdin(Stdio::piped()).stdout(Stdio::piped());
-        if let Some(fzf_opts) = config::fzf_opts() {
-            command.env("FZF_DEFAULT_OPTS", fzf_opts);
-        } else {
-            command.args(&[
-                // Search result
-                "--no-sort",
-                // Interface
-                "--keep-right",
-                // Layout
-                "--height=50%",
-                "--info=inline",
-                "--layout=reverse",
-                // Scripting
-                "--exit-0",
-                "--select-1",
-                // Key/Event bindings
-                "--bind=ctrl-z:ignore",
-            ]);
-            if cfg!(unix) {
-                // Non-POSIX args are only available on certain operating systems.
-                const LS_ARGS: &str = if cfg!(target_os = "linux") {
-                    "--color=always --group-directories-first"
-                } else if cfg!(target_os = "macos") {
-                    "--color=always"
-                } else {
-                    ""
-                };
-                command
-                    .args(&[&format!(r"--preview=\command -p ls -Cp {LS_ARGS} {{2..}}"), "--preview-window=down,30%"])
-                    .env("SHELL", "sh");
-            }
-        }
+        let program = "fzf";
 
-        let child = match command.spawn() {
-            Ok(child) => child,
-            Err(e) if e.kind() == io::ErrorKind::NotFound => bail!(ERR_FZF_NOT_FOUND),
-            Err(e) => Err(e).context("could not launch fzf")?,
-        };
+        let mut cmd = Command::new(program);
+        cmd.args([
+            // Search mode
+            "--delimiter=\t",
+            "--nth=2",
+            // Scripting
+            "--read0",
+        ])
+        .stdin(Stdio::piped())
+        .stdout(Stdio::piped());
 
-        Ok(Fzf { child })
+        Ok(Fzf(cmd))
     }
 
-    pub fn stdin(&mut self) -> &mut ChildStdin {
-        self.child.stdin.as_mut().unwrap()
+    pub fn enable_preview(&mut self) -> &mut Self {
+        // Previews are only supported on UNIX.
+        if !cfg!(unix) {
+            return self;
+        }
+
+        self.args([
+            // Non-POSIX args are only available on certain operating systems.
+            if cfg!(target_os = "linux") {
+                r"--preview=\command -p ls -Cp --color=always --group-directories-first {2..}"
+            } else {
+                r"--preview=\command -p ls -Cp {2..}"
+            },
+            // Rounded edges don't display correctly on some terminals.
+            "--preview-window=down,30%,sharp",
+        ])
+        .envs([
+            // Enables colorized `ls` output on macOS / FreeBSD.
+            ("CLICOLOR", "1"),
+            // Forces colorized `ls` output when the output is not a
+            // TTY (like in fzf's preview window) on macOS /
+            // FreeBSD.
+            ("CLICOLOR_FORCE", "1"),
+            // Ensures that the preview command is run in a
+            // POSIX-compliant shell, regardless of what shell the
+            // user has selected.
+            ("SHELL", "sh"),
+        ])
     }
 
-    pub fn select(mut self) -> Result<String> {
+    pub fn args<I, S>(&mut self, args: I) -> &mut Self
+    where
+        I: IntoIterator<Item = S>,
+        S: AsRef<OsStr>,
+    {
+        self.0.args(args);
+        self
+    }
+
+    pub fn env<K, V>(&mut self, key: K, val: V) -> &mut Self
+    where
+        K: AsRef<OsStr>,
+        V: AsRef<OsStr>,
+    {
+        self.0.env(key, val);
+        self
+    }
+
+    pub fn envs<I, K, V>(&mut self, vars: I) -> &mut Self
+    where
+        I: IntoIterator<Item = (K, V)>,
+        K: AsRef<OsStr>,
+        V: AsRef<OsStr>,
+    {
+        self.0.envs(vars);
+        self
+    }
+
+    pub fn spawn(&mut self) -> Result<FzfChild> {
+        match self.0.spawn() {
+            Ok(child) => Ok(FzfChild(child)),
+            Err(e) if e.kind() == io::ErrorKind::NotFound => bail!(Self::ERR_FZF_NOT_FOUND),
+            Err(e) => Err(e).context("could not launch fzf"),
+        }
+    }
+}
+
+pub struct FzfChild(Child);
+
+impl FzfChild {
+    pub fn write(&mut self, dir: &Dir, now: Epoch) -> Result<Option<String>> {
+        let handle = self.0.stdin.as_mut().unwrap();
+        match write!(handle, "{}\0", dir.display().with_score(now).with_separator('\t')) {
+            Ok(()) => Ok(None),
+            Err(e) if e.kind() == io::ErrorKind::BrokenPipe => self.wait().map(Some),
+            Err(e) => Err(e).context("could not write to fzf"),
+        }
+    }
+
+    pub fn wait(&mut self) -> Result<String> {
         // Drop stdin to prevent deadlock.
-        mem::drop(self.child.stdin.take());
+        mem::drop(self.0.stdin.take());
 
-        let mut stdout = self.child.stdout.take().unwrap();
+        let mut stdout = self.0.stdout.take().unwrap();
         let mut output = String::new();
         stdout.read_to_string(&mut output).context("failed to read from fzf")?;
 
-        let status = self.child.wait().context("wait failed on fzf")?;
+        let status = self.0.wait().context("wait failed on fzf")?;
         match status.code() {
             Some(0) => Ok(output),
             Some(1) => bail!("no match found"),
             Some(2) => bail!("fzf returned an error"),
-            Some(code @ 130) => bail!(SilentExit { code }),
+            Some(130) => bail!(SilentExit { code: 130 }),
             Some(128..=254) | None => bail!("fzf was terminated"),
             _ => bail!("fzf returned an unknown error"),
         }
@@ -117,10 +164,11 @@ pub fn write<P: AsRef<Path>, C: AsRef<[u8]>>(path: P, contents: C) -> Result<()>
         // Set the owner of the tmpfile (UNIX only).
         #[cfg(unix)]
         if let Ok(metadata) = path.metadata() {
-            use nix::unistd::{self, Gid, Uid};
             use std::os::unix::fs::MetadataExt;
             use std::os::unix::io::AsRawFd;
 
+            use nix::unistd::{self, Gid, Uid};
+
             let uid = Uid::from_raw(metadata.uid());
             let gid = Gid::from_raw(metadata.gid());
             let _ = unistd::fchown(tmp_file.as_raw_fd(), Some(uid), Some(gid));
@@ -158,31 +206,30 @@ fn tmpfile<P: AsRef<Path>>(dir: P) -> Result<(File, PathBuf)> {
         // Atomically create the tmpfile.
         match OpenOptions::new().write(true).create_new(true).open(&path) {
             Ok(file) => break Ok((file, path)),
-            Err(e) if e.kind() == io::ErrorKind::AlreadyExists && attempts < MAX_ATTEMPTS => (),
-            Err(e) => break Err(e).with_context(|| format!("could not create file: {}", path.display())),
+            Err(e) if e.kind() == io::ErrorKind::AlreadyExists && attempts < MAX_ATTEMPTS => {}
+            Err(e) => {
+                break Err(e).with_context(|| format!("could not create file: {}", path.display()));
+            }
         }
     }
 }
 
-/// Similar to [`fs::rename`], but retries on Windows.
+/// Similar to [`fs::rename`], but with retries on Windows.
 fn rename<P: AsRef<Path>, Q: AsRef<Path>>(from: P, to: Q) -> Result<()> {
-    const MAX_ATTEMPTS: usize = 5;
     let from = from.as_ref();
     let to = to.as_ref();
 
-    if cfg!(windows) {
-        let mut attempts = 0;
-        loop {
-            attempts += 1;
-            match fs::rename(from, to) {
-                Err(e) if e.kind() == io::ErrorKind::PermissionDenied && attempts < MAX_ATTEMPTS => (),
-                result => break result,
+    const MAX_ATTEMPTS: usize = if cfg!(windows) { 5 } else { 1 };
+    let mut attempts = 0;
+
+    loop {
+        match fs::rename(from, to) {
+            Err(e) if e.kind() == io::ErrorKind::PermissionDenied && attempts < MAX_ATTEMPTS => attempts += 1,
+            result => {
+                break result.with_context(|| format!("could not rename file: {} -> {}", from.display(), to.display()))
             }
         }
-    } else {
-        fs::rename(from, to)
     }
-    .with_context(|| format!("could not rename file: {} -> {}", from.display(), to.display()))
 }
 
 pub fn canonicalize<P: AsRef<Path>>(path: &P) -> Result<PathBuf> {
@@ -298,7 +345,7 @@ pub fn resolve_path<P: AsRef<Path>>(path: &P) -> Result<PathBuf> {
     for component in components {
         match component {
             Component::Normal(_) => stack.push(component),
-            Component::CurDir => (),
+            Component::CurDir => {}
             Component::ParentDir => {
                 if stack.last() != Some(&Component::RootDir) {
                     stack.pop();
